@@ -2,7 +2,7 @@ from __future__ import annotations
 from abc import abstractmethod
 
 from pydantic import BaseModel
-from typing import Callable, Iterator, get_type_hints, Union, Any, Optional
+from typing import Callable, Iterable, Iterator, get_type_hints, Union, Any, Optional
 
 from .query import get_filtration
 
@@ -32,20 +32,10 @@ class FieldsView:
     __repr__ = __str__
 
 
-IGNORE_FIELDS_ATTR_NAME = "__ignore_fields__"
-
-
 class Filterable:
     @classmethod
     def fields(cls, table_name: Optional[str] = None) -> FieldsView:
-        res = FieldsView(
-            set(get_type_hints(cls))
-            - (
-                set()
-                if not hasattr(cls, IGNORE_FIELDS_ATTR_NAME)
-                else set(getattr(cls, IGNORE_FIELDS_ATTR_NAME))
-            )
-        )
+        res = FieldsView(set(get_type_hints(cls)) - cls.__ignore_fields__())
         if table_name is None:
             return res
         return table_name @ res
@@ -53,3 +43,7 @@ class Filterable:
     @classmethod
     def filter(cls) -> Callable:
         return get_filtration(cls.fields())
+
+    @classmethod
+    def __ignore_fields__(cls) -> set[str]:
+        return set()
